# Code of Conduct

The {{ cookiecutter.project_name }} is made up of members with a diverse set of
skills, personalities, and experiences. It is through these differences that our
community experiences great successes and continued growth. When you're working
with members of the community, this Code of Conduct will help steer your
interactions and keep {{ cookiecutter.project_name }} a positive, successful,
and growing community.

## Our Community

Members of the {{ cookiecutter.project_name }} are open, considerate, and
respectful. Behaviours that reinforce these values contribute to a positive
environment, and include:

- **Being open**. Members of the community are open to collaboration, whether
  it's on PEPs, patches, problems, or otherwise.
- **Focusing on what is best for the community**. We're respectful of the
  processes set forth in the community, and we work within them.
- **Acknowledging time and effort.** We're respectful of the volunteer efforts
  that permeate the {{ cookiecutter.project_name }} community. We're thoughtful
  when addressing the efforts of others, keeping in mind that often times the
  labor was completed simply for the good of the community.
- **Being respectful of differing viewpoints and experiences.** We're receptive
  to constructive comments and criticism, as the experiences and skill sets of
  other members contribute to the whole of our efforts.
- **Showing empathy towards other community members.** We're attentive in our
  communications, whether in person or online, and we're tactful when
  approaching differing views.
- **Being considerate.** Members of the community are considerate of their peers
  -- other {{ cookiecutter.project_name }} users. **Being respectful.- ** We're
  respectful of others, their positions, their skills, their commitments, and
  their efforts.
- **Gracefully accepting constructive criticism**. When we disagree, we are
  courteous in raising our issues.
- **Using welcoming and inclusive language.** We're accepting of all who wish to
  take part in our activities, fostering an environment where anyone can
  participate and everyone can make a difference.

## Our Standards

Every member of our community has the right to have their identity respected.
The {{ cookiecutter.project_name }} community is dedicated to providing a
positive experience for everyone, regardless of age, gender identity and
expression, sexual orientation, disability, physical appearance, body size,
ethnicity, nationality, race, or religion (or lack thereof), education, or
socio-economic status.

### Inappropriate Behavior

Examples of unacceptable behavior by participants include:

- Harassment of any participants in any form
- Deliberate intimidation, stalking, or following
- Logging or taking screenshots of online activity for harassment purposes
- Publishing others' private information, such as a physical or electronic
  address, without explicit permission
- Violent threats or language directed against another person
- Incitement of violence or harassment towards any individual, including
  encouraging a person to commit suicide or to engage in self-harm
- Creating additional online accounts in order to harass another person or
  circumvent a ban
- Sexual language and imagery in online communities or in any conference venue,
  including talks
- Insults, put downs, or jokes that are based upon stereotypes, that are
  exclusionary, or that hold others up for ridicule
- Excessive swearing
- Unwelcome sexual attention or advances
- Unwelcome physical contact, including simulated physical contact (eg, textual
  descriptions like "hug" or "backrub") without consent or after a request to
  stop
- Pattern of inappropriate social contact, such as requesting/assuming
  inappropriate levels of intimacy with others
- Sustained disruption of online community discussions, in-person presentations,
  or other in-person events
- Continued one-on-one communication after requests to cease
- Other conduct that is inappropriate for a professional audience including
  people of many different backgrounds

Community members asked to stop any inappropriate behavior are expected to
comply immediately.

## Consequences

If a participant engages in behavior that violates this code of conduct, the
{{ cookiecutter.project_name }} community Code of Conduct team may take any
action they deem appropriate, including warning the offender or expulsion from
the community. The full list of consequences for inappropriate behavior is
listed in << link to your consequences document >>.

Thank you for helping make this a welcoming, friendly community for everyone.

**Contact Information** If you believe that someone is violating the code of
conduct, or have any other concerns, please contact a member of the
{{ cookiecutter.project_name }} work group immediately. They can be reached by
emailing << Add your email >>.

## License

This Code of Conduct is licensed under the << add a license >>.

## Attributions

This Code of Conduct was adapted from the
[Python Community Code of Conduct](https://www.python.org/psf/conduct/), which
is licensed under the
[Creative Commons Attribution-ShareAlike 3.0 Unported License](https://creativecommons.org/licenses/by-sa/3.0/).
The Python Code of Conduct itself is a derivative of the example policy from the
[Geek Feminism wiki, created by the Ada Initiative and other volunteers](http://geekfeminism.wikia.com/wiki/Conference_anti-harassment/Policy),
which is released under a
[Creative Commons Zero license](https://creativecommons.org/publicdomain/zero/1.0/).
